searchData={"items":[{"type":"module","title":"AuthToken","doc":"Simplified encrypted authentication tokens using JWE.\n\nConfiguration needed:\n\n  config :authtoken,\n    token_key: PUT_KEY_HERE\n\nGenerate a token for your user after successful authentication like this:","ref":"AuthToken.html"},{"type":"module","title":"Examples - AuthToken","doc":"token_content = %{userid: user.id}\n\n    token = AuthToken.generate_token(token_content)","ref":"AuthToken.html#module-examples"},{"type":"function","title":"AuthToken.decrypt_token/1","doc":"Decrypt an authentication token\n\nFormat \"bearer: tokengoeshere\" and \"bearer tokengoeshere\" will be accepted and parsed out.","ref":"AuthToken.html#decrypt_token/1"},{"type":"function","title":"AuthToken.generate_key/0","doc":"Generate a random key for AES128","ref":"AuthToken.html#generate_key/0"},{"type":"function","title":"Examples - AuthToken.generate_key/0","doc":"iex> AuthToken.generate_key()\n    {:ok, <<153, 67, 252, 211, 199, 186, 212, 114, 109, 99, 222, 205, 31, 26, 100, 253>>}","ref":"AuthToken.html#generate_key/0-examples"},{"type":"function","title":"AuthToken.generate_token/1","doc":"Generates an encrypted auth token.\n\nContains an encoded version of the provided map, plus a timestamp for timeout and refresh.","ref":"AuthToken.html#generate_token/1"},{"type":"function","title":"AuthToken.get_config/1","doc":"","ref":"AuthToken.html#get_config/1"},{"type":"function","title":"AuthToken.is_timedout?/1","doc":"Check if token is timedout and not valid anymore","ref":"AuthToken.html#is_timedout?/1"},{"type":"function","title":"AuthToken.needs_refresh?/1","doc":"Check if token is stale and needs to be refreshed","ref":"AuthToken.html#needs_refresh?/1"},{"type":"function","title":"AuthToken.refresh_token/1","doc":"Checks a token and refreshes if necessary.","ref":"AuthToken.html#refresh_token/1"},{"type":"function","title":"Examples - AuthToken.refresh_token/1","doc":"case AuthToken.refresh_token(token) do\n      {:error, :timedout} ->\n        # Redirect to login\n      {:error, :stillfresh} ->\n        # Do nothing\n      {:ok, token} ->\n        # Check credentials and send back new token\n    end","ref":"AuthToken.html#refresh_token/1-examples"},{"type":"module","title":"AuthToken.Plug","doc":"Plugs for AuthToken","ref":"AuthToken.Plug.html"},{"type":"module","title":"Examples - AuthToken.Plug","doc":"import AuthToken.Plug\n\n    pipeline :auth do\n      plug :verify_token\n    end\n\n    scope \"/protected/route\", MyApp do\n      pipe_through :auth\n\n      resources \"/\", DoNastyStuffController\n    end","ref":"AuthToken.Plug.html#module-examples"},{"type":"function","title":"AuthToken.Plug.verify_token/2","doc":"Checks authentication token from authorization header.\n\nIf this fails, send 401 with message \"error\": \"auth_fail\" or \"error\": \"timeout\" as JSON","ref":"AuthToken.Plug.html#verify_token/2"},{"type":"extras","title":"Authtoken","doc":"# Authtoken\n\n[![Travis CI Build Status](https://travis-ci.org/Brainsware/authtoken.svg?branch=master)](https://travis-ci.org/Brainsware/authtoken)\n![Elixir CI](https://github.com/sealas/authtoken/workflows/Elixir%20CI/badge.svg)\n\nSimplified encrypted authentication tokens using JWE.\n\nThis package provides you with a simplified headerless and encrypted JWT. It provides you with sane defaults (AES128) and almost no configuration to counteract JWTs overblown standard. See this [blog post](https://sealas.at/blog/2017-12/tokens-cookies-and-sessions-an-auth-story-part-1/) for more information.\n\nExample integration here in [Sealas](https://github.com/Brainsware/sealas)","ref":"readme.html"},{"type":"extras","title":"Installation - Authtoken","doc":"1. Add `authtoken` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:authtoken, \"~> 0.3\"}\n  ]\nend\n```\n\n2. Configure `authtoken`. The minimum amount of configuration needed is a key for encryption.\n\n```elixir\nconfig :authtoken,\n  token_key: <<1, 2, 3, 230, 103, 242, 149, 254, 4, 33, 137, 240, 23, 90, 99, 250>>\n```\n\nYou can generate this with\n\n```elixir\niex> AuthToken.generate_key()\n{:ok, <<1, 2, 3, 230, 103, 242, 149, 254, 4, 33, 137, 240, 23, 90, 99, 250>>}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Authtoken","doc":"Generate a token for your user after successful authentication like this:\n\n```elixir\ntoken_content = %{userid: user.id}\n\n{:ok, token} = AuthToken.generate_token(token_content)\n```\n\nthen pass it on to your view.\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Get the content / Decrypting - Authtoken","doc":"The most likely use-case is going to be you wanting to decrypt a token you have received in the request headers.\n\n```elixir\n{:ok, token} = AuthToken.decrypt_token(conn)\n\nuser_id = token.userid\n```\n\n#","ref":"readme.html#get-the-content-decrypting"},{"type":"extras","title":"Refreshing - Authtoken","doc":"By default a token should be refreshed every 30 minutes, using `AuthToken.refresh_token/1`.\nYou can pass either a decrypted token, or simply the token you get from the client directly.\nThis will extend the lifetime of the token for another 30 minutes until it expires completely.\nYou can use this opportunity to check if the user's credentials haven't been revoked in the meantime.\n\n```elixir\ncase AuthToken.refresh_token(token) do\n  {:error, :timedout} ->\n    # Redirect to login\n  {:error, :stillfresh} ->\n    # Do nothing\n  {:ok, token} ->\n    # Check credentials and send back new token\nend\n```\n\n#","ref":"readme.html#refreshing"},{"type":"extras","title":"Plug - Authtoken","doc":"For verification you can use the plug `AuthToken.Plug.verify_token`.\n\n```elixir\nimport AuthToken.Plug\n\npipeline :auth do\n  plug :verify_token\nend\n\nscope \"/protected/route\", MyApp do\n  pipe_through :auth\n\n  resources \"/\", DoNastyStuffController\nend\n```\n\nMore detailed documentation can be found here: [https://hexdocs.pm/authtoken](https://hexdocs.pm/authtoken).","ref":"readme.html#plug"},{"type":"extras","title":"Configuration - Authtoken","doc":"More optional configuration options\n\n#","ref":"readme.html#configuration"},{"type":"extras","title":"timeout (default: 86400) - Authtoken","doc":"Denotes the lifetime of a token in seconds. After it expires you need to generate a new one.\n\n#","ref":"readme.html#timeout-default-86400"},{"type":"extras","title":"refresh (default: 1800) - Authtoken","doc":"The total duration after which the token needs to be refreshd","ref":"readme.html#refresh-default-1800"}],"content_type":"text/markdown"}